@@ -137,6 +137,20 @@ FLOAT_DTYPES = [
     float8_e8m0fnu,
 ]
 
+NUMPY_DTYPES = [
+    np.int8,
+    np.int16,
+    np.int32,
+    np.int64,
+    np.uint8,
+    np.uint16,
+    np.uint32,
+    np.uint64,
+    np.float16,
+    np.float32,
+    np.float64,
+]
+
 # Values that should round trip exactly to float and back.
 # pylint: disable=g-complex-comprehension
 FLOAT_VALUES = {
@@ -229,6 +243,9 @@ INT_VALUES = {
         "testPickleable",
         "testRoundTripNumpyTypes",
         "testRoundTripToNumpy",
+        "testConstructFromDtype",
+        "testHashNumbers",
+        "testHashNan",
     ],
 )
 @parameterized.named_parameters(
@@ -604,6 +621,41 @@ class CustomFloatTest(parameterized.TestCase):
     self.assertEqual(dt.name, name)
     self.assertEqual(repr(dt), f"dtype({name})")
 
+  def testConstructFromDtype(self, float_type):
+    for np_dtype in NUMPY_DTYPES:
+      with self.subTest(np_dtype.__name__):
+        expected = float_type(1)
+        actual = float_type(np_dtype(1))
+        self.assertEqual(type(expected), type(actual))
+        self.assertEqual(float(expected), float(actual))
+
+  def testByteSwap(self, float_type):
+    """Test that byteswap works correctly."""
+    arr = np.array([1.0, 2.0, 3.0], dtype=float_type)
+    original_bytes = arr.tobytes()
+
+    # Test copy byteswap
+    swapped = arr.byteswap(inplace=False)
+    self.assertIsNot(swapped, arr)  # Different object
+    self.assertEqual(arr.tobytes(), original_bytes)  # Original unchanged
+
+    if np.dtype(float_type).itemsize == 2:
+      # 16-bit types should swap bytes
+      self.assertNotEqual(original_bytes, swapped.tobytes())
+
+      # Test in-place byteswap
+      arr_copy = arr.copy()
+      result = arr_copy.byteswap(inplace=True)
+      self.assertIs(result, arr_copy)  # Same object
+      self.assertEqual(arr_copy.tobytes(), swapped.tobytes())  # Same bytes
+
+      # Double swap restores original
+      arr_copy.byteswap(inplace=True)
+      self.assertEqual(arr_copy.tobytes(), original_bytes)
+    else:
+      # 8-bit types should be unchanged
+      self.assertEqual(original_bytes, swapped.tobytes())
+
 
 BinaryOp = collections.namedtuple("BinaryOp", ["op"])
 
@@ -685,8 +737,10 @@ BINARY_PREDICATE_UFUNCS = [
     skip_tests=[
         "testBinaryPredicateUfunc",
         "testBinaryUfunc",
+        "testCanCast",
         "testCasts",
         "testConformNumpyComplex",
+        "testCopySign",  # pytest 9.0.1's subtest appears not to be thread-safe
         "testDivmod",
         "testDivmodCornerCases",
         "testFloordivCornerCases",
